@@ -4,8 +4,66 @@ use warnings;
 use 5.010; # state
 
 # ABSTRACT: Fully UTF-8 aware Cwd
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
+#pod =for test_synopsis
+#pod my $file;
+#pod
+#pod =head1 SYNOPSIS
+#pod
+#pod     # Using the utf-8 versions of cwd, getcwd, fastcwd, fastgetcwd
+#pod     use Cwd::utf8;
+#pod     my $dir = getcwd;
+#pod
+#pod     # Using the utf-8 versions of abs_path
+#pod     use Cwd::utf8 qw(abs_path);
+#pod     my $abs_path = abs_path($file);
+#pod
+#pod     # Exporting no functions
+#pod     use Cwd::utf8 qw(:none); # NOT "use Cwd::utf8 qw();"!
+#pod     my $real_path = Cwd::real_path($file);
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod While the original L<Cwd> functions are capable of handling UTF-8
+#pod quite well, they expects and return all data as bytes, not as
+#pod characters.
+#pod
+#pod This module replaces all the L<Cwd> functions with fully UTF-8 aware
+#pod versions, both expecting and returning characters.
+#pod
+#pod B<Note:> Replacement of functions is not done on DOS and OS/2
+#pod as these systems do not have full UTF-8 file system support.
+#pod
+#pod =head2 Behaviour
+#pod
+#pod The module behaves as a pragma so you can use both C<use
+#pod Cwd::utf8> and C<no Cwd::utf8> to turn utf-8 support on
+#pod or off.
+#pod
+#pod By default, cwd(), getcwd(), fastcwd(), and fastgetcwd() (and, on
+#pod Win32, getdcwd()) are exported (as with the original L<Cwd>). If you
+#pod want to prevent this, use C<use Cwd::utf8 qw(:none)>. (As all the
+#pod magic happens in the module's import function, you can not simply use
+#pod C<use Cwd::utf8 qw()>)
+#pod
+#pod =head1 COMPATIBILITY
+#pod
+#pod The filesystems of Dos, Windows, and OS/2 do not (fully) support
+#pod UTF-8. The L<Cwd> function will therefore not be replaced on these
+#pod systems.
+#pod
+#pod =head1 SEE ALSO
+#pod
+#pod =for :list
+#pod * L<Cwd> -- The original module
+#pod * L<File::Find::utf8> -- Fully utf-8 aware versions of the L<File::Find>
+#pod   functions.
+#pod * L<utf8::all> -- Turn on utf-8, all of it.
+#pod   This was also the module I first added the utf-8 aware versions of
+#pod   L<Cwd> and L<File::Find> to before moving them to their own package.
+#pod
+#pod =cut
 
 use Cwd qw();
 use Encode;
@@ -31,9 +89,9 @@ sub import {
     no strict qw(refs); ## no critic (TestingAndDebugging::ProhibitNoStrict)
     no warnings qw(redefine);
 
-    # If run on the DOS or OS/2 platform, ignore overriding functions silently.
-    # These platforms do not (properly) suppport utf-8 filenames...
-    unless ($^O eq 'dos' or $^O eq 'os2') {
+    # If run on the dos/os2/windows platform, ignore overriding functions silently.
+    # These platforms do have (proper) utf-8 file system suppport...
+    unless ($^O =~ /MSWin32|cygwin|dos|os2/) {
         no strict qw(refs); ## no critic (TestingAndDebugging::ProhibitNoStrict)
         no warnings qw(redefine);
 
@@ -69,14 +127,18 @@ sub import {
             *{$target_package . '::' . $f} = \&{$original_package . '::' . $f};
         }
     }
+
+    return;
 }
 
 sub unimport {
     # If run on the dos/os2/windows platform, ignore overriding functions silently.
-    # These platforms do not (properly) suppport utf-8 filenames...
-    unless ($^O eq 'Win32' or $^O eq 'dos' or $^O eq 'os2') {
+    # These platforms do have (proper) utf-8 file system suppport...
+    unless ($^O =~ /MSWin32|cygwin|dos|os2/) {
         $^H{$current_package} = 0; # Set compiler hint that we should not use the utf-8 version
     }
+
+    return;
 }
 
 sub _utf8_cwd {
@@ -106,7 +168,7 @@ Cwd::utf8 - Fully UTF-8 aware Cwd
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -157,21 +219,27 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 COMPATIBILITY
+
+The filesystems of Dos, Windows, and OS/2 do not (fully) support
+UTF-8. The L<Cwd> function will therefore not be replaced on these
+systems.
+
 =head1 SEE ALSO
 
 =over 4
 
 =item *
 
-L<Cwd>
+L<Cwd> -- The original module
 
 =item *
 
-L<File::Find::utf8>
+L<File::Find::utf8> -- Fully utf-8 aware versions of the L<File::Find> functions.
 
 =item *
 
-L<utf8::all>
+L<utf8::all> -- Turn on utf-8, all of it. This was also the module I first added the utf-8 aware versions of L<Cwd> and L<File::Find> to before moving them to their own package.
 
 =back
 
